macro_file MultiCut; // Tab setting for this file is 2
/**************************Multi-Edit Macro*********************************
												MultiCut Version 1.00
										 Written by Donald K Forbes
							(Modifications for buffer viewing by Al O'Donnell
 								- fixes by Kevin R Jackson, Roy Jennings)

MultiCut		- Copies, copy/Appends, Moves or mOve/Appends a block
							 into 1 of N  hidden buffers. 26 is the default (User
							 configurable.) Put
							 Set_Global_Int('@MCMaxBuffers', <x>);
							 in your startup to set 'N'.
MultiPaste  - Copies a block from 1 of 26 hidden buffers into current
							 file.
MultiSwitch - Switch backward or forward (next or previous buffer).
MultiMenu   - Multi Cut and Paste menu.

MultiView		- Browse the cut buffers to select the one you want! Allows deleting
							buffers, and marking them as "read-only" to protect them.

These macros implement a 26 buffer cut and paste system that can be
implemented in one of two ways (or both):

	1.  A cut and paste system where you specify on which of the 26
			buffers the operation is to be performed.

	2.  A cut and paste system that uses each of the 26 buffers in a
			circular queue.

	3.  Both (might be confusing).

In the first method every time you copy or move a block to a buffer
you must specify to which buffer the copy or move is to be performed
and every time you want to paste from a buffer you must specify from
which buffer the paste is to be performed.  If you do an 'Append to
buffer' operation the current block is appended to the buffer you
specify.

In the second method every time you copy or move a block to a buffer
the block is copied or moved to one of the buffers in a circular
queue.  Each consecutive time you do a copy or move, the operation is
performed on the next buffer in the queue until buffer 26 is reached.
When buffer 26 is reached the next buffer in the queue becomes buffer
1.  If you do an 'Append to buffer' operation the contents of the
previous buffer in the queue are copied to the current buffer in the
queue and the current block is then appended to the current buffer in
the queue.  You can also switch to the previous or next buffer in the
queue with this method.

Although it may become confusing, both methods mentioned above can be
used in the same edit session and both methods use the same 26
buffers.  The 26 buffers that are used by these macros are numbered 1
through 26 (A through Z) and are separate from buffer 0 that is used
by Multi-Edit's cut and paste macros.

Key assignments:

	Ŀ
	                                                                          
	                   Multi Cut and Paste Method 1                           
	                                                                          
	Description                       Macro      Parameter     Menu Identifier
	Ĵ
	Copy block to buffer 1..26       MultiCut   /O=1        !MCPM_KEY1     
	Copy/Append block to buffer 1..26MultiCut   /A/O=1      !MCPM_KEY2     
	Move block to buffer 1..26       MultiCut   /M/O=1      !MCPM_KEY3     
	Move/Append block to buffer 1..26MultiCut   /M/A/O=1    !MCPM_KEY4     
	Paste from buffer 1..26          MultiPaste /O=1        !MCPM_KEY5     
	View cut buffers                 MultiView  /O=1        !MCPM_KEY6     
	Multi cut and paste 1..26 menu   MultiMenu  /Q=0        !MCPM_KEY      
	

	Ŀ
	                                                                          
	                   Multi Cut and Paste Method 2                           
	                                                                          
	Description                       Macro      Parameter     Menu Identifier
	Ĵ
	Copy block to queue              MultiCut   /O=1/Q=1    !MCPMQ_KEY1    
	Copy/Append block to queue       MultiCut   /A/O=1/Q=1  !MCPMQ_KEY2    
	Move block to queue              MultiCut   /M/O=1/Q=1  !MCPMQ_KEY3    
	Move/Append block to queue       MultiCut   /M/A/O=1/Q=1!MCPMQ_KEY4    
	Paste from Queue                 MultiPaste /O=1/Q=1    !MCPMQ_KEY5    
	Move backward in queue           MultiSwitch/D=0        !MCPMQ_KEY6    
	Move forward in queue            MultiSwitch/D=1        !MCPMQ_KEY7    
	View cut buffers                 MultiView  /O=1        !MCPMQ_KEY8    
	Multi cut and paste queue menu   MultiMenu  /Q=1        !MCPMQ_KEY     
	

NOTE:  1.	All keymap settings listed above require the 'Macro file'
					parameter to be set to 'MultiCut'

			 2. The '/O=1' parameters listed above causes the currenly
					marked block to be turned off immediately after the copy,
					move or paste operation; if this is not desirable, remove
					them.

The following are the keys I used for testing these macros and are
not necessarily recommended:
														          
                           Method 1Method 2 
																		  
														Ŀ
	Multi Cut/Paste 1..26 menuAltShftF1AltShftF2 Multi Cut/Paste queue menu
														
														Ŀ
				Copy to buffer 1..26AltShftF1AltShftF2 Copy to queue
														Ĵ
 copy/Append to buffer 1..26AltShftF3AltShftF4 copy/Append to queue
														Ĵ
				Move to buffer 1..26AltShftF5AltShftF6 Move to queue
														Ĵ
 mOve/append to buffer 1..26AltShftF7AltShftF8 mOve/append to queue
														Ĵ
		 Paste from buffer 1..26AltShftF9AltShftF10Paste from queue
														
																		Ŀ
																		AltShftGREY-- move backward in queue
																		
																		Ŀ
																		AltShftGREY++ move forward in queue
																		

	NOTE: See below for 6.0/7.0 compilation!

						(C) Copyright 1992 American Cybernetics, Inc.
****************************************************************************/
/* Probably should NEVER BE OVER 26, although I tried 40 and it worked! */
#define MAX_BUFFERS				26
// #define _BUFFER_NAME me_path+'!BUF'+User_Id+'.'
/* for 6.0, uncomment the above line, and comment the following two: */
#include src\mesys.sh
#define _BUFFER_NAME getuserpath( FALSE ) + 'BUFFER.'

/**************************Multi-Edit Macro*********************************

 NAME:         MultiCut

 DESCRIPTION:  Copies or moves the currently marked block to 1 of 26 hidden
							 buffers; erases or retains the contents of the hidden buffer.

 PARAMETERS:   /M  - If present, moves the block else copies the block.
							 /A  - If present, appends the block to the hidden buffer else
											 erases the contents of the hidden buffer.
							 /O= - If non-zero the currently marked block will be turned
											 off after the block operation.
							 /Q= - If non-zero use the buffers in a circular queue.
							 /X= - The starting screen column.
							 /Y= - The starting screen line.

 RETURNS:      Nothing.

						(C) Copyright 1992 American Cybernetics, Inc.
****************************************************************************/
macro MultiCut Trans2
{
	str		OParm[8]='/O='+Str(Parse_Int('/O=',MParm_Str)),
				Operation='Copy';

	int		i,Menu=Menu_Create,Next=Global_Int('@MCNextBuf'), Cur,
				Queue=Parse_Int('/Q=',MParm_Str),LastMenu=1,
				cwin = cur_window, done = TRUE, count=0,OldRefresh=Refresh;

	Push_Undo;
	Refresh = FALSE;
	Cur = Next;
	if ((Global_Int('@MCMaxBuffers')< 1) || (Global_Int('@MCMaxBuffers') > MAX_BUFFERS)) {
		Set_Global_Int('@MCMaxBuffers', MAX_BUFFERS);
	}
	if ( Xpos('/M',MParm_Str,1) )
	{
		OParm=OParm+'/M';
		Operation='Move';
		LastMenu+=2;
	}

	if ( Xpos('/A', MParm_Str,1) )
	{
		OParm=OParm+'/A';
		Operation=Operation+'//Append';
		LastMenu+=1;
	}
	if ( !Queue )
	{
		Operation=Operation+' block to buffer.  Select buffer to use';
	}

	do {
		done = TRUE;
		switch_window(cwin);
		if ( !Queue ) {
			for ( i = 1; i < (Global_Int('@MCMaxBuffers')+1); i++ )
				Menu_Set_Item(Menu,i,Char(i+0x40),'','',0, 0,0);

			Return_Int=Menu;
			rm('UserIn^TopMenu /HN=1/#=' + str(Global_Int('@MCMaxBuffers')) + '/L='+Operation+'/S='+Str(Next)+'/X='+
					Parse_Str('/X=',MParm_Str)+'/Y='+Parse_Str('/Y=',MParm_Str));
		}
		else
		{
			count++;
			if ( (Global_Int('@MCMaxBuffers')+1) <= (Return_Int=(++Next)) ) {
				Return_Int=1;
				Next = 1;
			}

			if ( XPos('/A',OParm,1) )
			{
				int TWin=Window_Id,ro = FALSE;

				if (switch_file((_BUFFER_NAME+Str(Return_Int)))) {
					if ( read_only ) {
						ro = TRUE;
					}
				}

				if (!ro && Switch_File(_BUFFER_NAME+Str(Cur)) )
				{
					int T_ML=Message_Length;
					Message_Length=0;
					rm('Cut /B='+Str(Return_int));
					Switch_Win_Id(TWin);
					Message_Length=T_ML;
				}
			}
		}

		if (switch_file((_BUFFER_NAME+Str(Return_Int)))) {
			if ( read_only ) {
				done = FALSE;
				if ( !Queue ) {
					RM("MEERROR^MessageBox /B=1/T=Read Only Buffer!/M=Select another buffer.");
				}
			}
		}
	} while ( !done && (count <= Global_Int('@MCMaxBuffers')));
	switch_window(cwin);

	if ( count >  Global_Int('@MCMaxBuffers')) {
		RM("MEERROR^MessageBox /B=1/T=No Free Buffer!/M=All Buffers are READ ONLY.");
	} else {
		if ( 0 != (Next=Return_Int) )
		{
			rm('Cut /B='+Str(Next)+OParm);
			Set_Global_Int('@MCNextBuf',Next);
			Set_Global_Int('@MCLastMenu',LastMenu);
		}
	}
	Refresh=OldRefresh;
	Redraw;
	Menu_Delete(Menu);
	Pop_Undo;
} // MultiCut

/**************************Multi-Edit Macro*********************************

 NAME:         MultiPaste

 DESCRIPTION:  Pastes the contents from 1 of 26 hidden buffres to the
							 current cursor position.

 PARAMETERS:   /O= - If non-zero the currently marked block will be turned
											 off after the block operation.
							 /Q= - If non-zero use the buffers in a circular queue.
							 /X= - The starting screen column.
							 /Y= - The starting screen line.

 RETURNS:      Nothing

						(C) Copyright 1992 American Cybernetics, Inc.
****************************************************************************/
macro MultiPaste Trans2
{
	str		OParm[4]='/O='+Str(0!=Parse_Int('/O=',MParm_Str));

	int		i,Menu=Menu_Create,Cur=Global_Int('@MCNextBuf');

	Push_Undo;
	if ((Global_Int('@MCMaxBuffers')< 1) || (Global_Int('@MCMaxBuffers') > MAX_BUFFERS)) {
		Set_Global_Int('@MCMaxBuffers', MAX_BUFFERS);
	}
	if ( !Parse_Int('/Q=',MParm_Str) )
	{
		for ( i = 1; i < (Global_Int('@MCMaxBuffers')+1); i++ )
			Menu_Set_Item(Menu,i,Char(i+0x40),'','',0, 0,0);

		Return_Int=Menu;
		rm('UserIn^TopMenu /HN=1/#=' + str(Global_Int('@MCMaxBuffers')) + '/L=Paste block from buffer.  '+
				'Select buffer to use/S='+Str(Cur)+'/X='+Parse_Str('/X=',
				MParm_Str)+'/Y='+Parse_Str('/Y=',MParm_Str));

		Cur=Return_Int;
	}
	else
	{
		if ( !Cur )
			Cur=1;

		Return_Int=Cur;
	}

	if ( 0 != (Cur=Return_Int))
	{
		rm('Paste /B='+Str(Cur)+OParm);
		Set_Global_Int('@MCNextBuf',Cur);
		Set_Global_Int('@MCLastMenu',5);
	}
	Menu_Delete(Menu);
	Pop_Undo;
} // MultiPaste

/**************************Multi-Edit Macro*********************************

 NAME:         MultiSwitch

 DESCRIPTION:  Move the current queue pointer backward or forward.

 PARAMETERS:	/D= Direction to move.  0 to move backward.
																			1 to move forward.

 RETURNS:      Nothing

						(C) Copyright 1992 American Cybernetics, Inc.
****************************************************************************/
macro MultiSwitch Trans2
{
	int Cur;

	if ((Global_Int('@MCMaxBuffers')< 1) || (Global_Int('@MCMaxBuffers') > MAX_BUFFERS)) {
		Set_Global_Int('@MCMaxBuffers', MAX_BUFFERS);
	}
	if ( Parse_Int('/D=',MParm_Str) )
		Cur=1;
	else
		Cur= -1;

	if ( 0 >= (Cur=(Global_Int('@MCNextBuf')+Cur)) )
		Cur=Global_Int('@MCMaxBuffers');
	else if ( (Global_Int('@MCMaxBuffers')+1) <= Cur )
		Cur=1;

	Make_Message('Switched to buffer '+char(Cur+0x40));
	Set_Global_Int('@MCNextBuf',Cur);
} // MultiSwitch

/**************************Multi-Edit Macro*********************************

 NAME:         MultiMenu

 DESCRIPTION:  Displays 1 of 2 menus for the multi cut and paste
							 system.

 PARAMETERS:	 /Q= - 0 Display menu for user selected system.
									 - 1 Display menu for queued system.
							 /X= - The starting screen column.
							 /Y= - The starting screen line.

 RETURNS:      Nothing

						(C) Copyright 1992 American Cybernetics, Inc.
****************************************************************************/
macro MultiMenu
{
	int i=1,Items=6+(2*(0!=Parse_Int('/Q=',MParm_Str))),Direction=0,
			Menu=Menu_Create,LastMenu=Global_Int('@MCLastMenu');

	str MenuTail[22],OParm[12]='/O='+Str(0!=Parse_Int('/O=',MParm_Str))+
			'/Q='+Str(0!=Parse_Int('/Q=',MParm_Str)),Q[1]='';

	if ((Global_Int('@MCMaxBuffers')< 1) || (Global_Int('@MCMaxBuffers') > MAX_BUFFERS)) {
		Set_Global_Int('@MCMaxBuffers', MAX_BUFFERS);
	}
	if ( Items == 6 )
		MenuTail=' block to buffer A..' + Char(Global_Int('@MCMaxBuffers')+0x40);
	else
	{
		MenuTail=' block to queue';
		Q='Q';
	}

	Menu_Set_Item(Menu,i,'Copy'+MenuTail,Global_Str('!MCPM'+Q+'_KEY'+Str(i)),
			'',0,0,0); i++;
	Menu_Set_Item(Menu,i,'copy/Append'+MenuTail,Global_Str('!MCPM'+Q+'_KEY'+Str(i)),
			'',0,0,0); i++;
	Menu_Set_Item(Menu,i,'Move'+MenuTail,Global_Str('!MCPM'+Q+'_KEY'+Str(i)),
			'',0,0,0); i++;
	Menu_Set_Item(Menu,i,'mOve/append'+MenuTail,Global_Str('!MCPM'+Q+'_KEY'+Str(i)),
			'',0,0,0); i++;
	if ( Items == 6 )
	{
		Menu_Set_Item(Menu,i,'Paste from buffer A..' + Char(Global_Int('@MCMaxBuffers')+0x40),Global_Str('!MCPM'+Q+'_KEY'+Str(i)),
				'',0,0,0); i++;
		Menu_Set_Item(Menu,i,'View Cut Buffers',Global_Str('!MCPM'+Q+'_KEY'+Str(i)),
				'',0,0,0); i++;
	}
	else
	{
		Menu_Set_Item(Menu,i,'Paste from queue',Global_Str('!MCPM'+Q+'_KEY'+Str(i)),
				'',0,0,0); i++;
		Menu_Set_Item(Menu,i,'- move backward',Global_Str('!MCPM'+Q+'_KEY'+Str(i)),
				'',0,0,0); i++;
		Menu_Set_Item(Menu,i,'+ move forward',Global_Str('!MCPM'+Q+'_KEY'+Str(i)),
				'',0,0,0); i++;
		Menu_Set_Item(Menu,i,'View Cut Buffers',Global_Str('!MCPM'+Q+'_KEY'+Str(i)),
				'',0,0,0); i++;
	}

	Return_Int=Menu;
	rm('UserIn^SubMenu /HN=1/#='+Str(Items)+'/L=MULTI CUT AND PASTE/S='+
			Str(LastMenu)+'/X='+Parse_Str('/X=',MParm_Str)+'/Y='+Parse_Str('/Y=',
			MParm_Str));

	if ( (Items == 6) && (Return_Int >= 6) ) {
		Return_int += 2;
	}
	Kill_Box;
	switch ( Return_Int )
	{
		case 4 :
			OParm=OParm+'/M';
		case 2 :
			OParm=OParm+'/A';
			rm('MultiCut '+OParm);
			break;

		case 3 :
			OParm=OParm+'/M';
		case 1 :
			rm('MultiCut '+OParm);
			break;

		case 5 :
			rm('MultiPaste '+OParm);
			break;

		case 7 :
			Direction=1;
		case 6 :
			Set_Global_Int('@MCLastMenu',Return_Int);
			rm('MultiSwitch /D='+Str(Direction));
			break;
		case 8:
			rm('MultiView '+OParm);
			Set_Global_Int('@MCLastMenu',Items);
			break;
	}
	Menu_Delete(Menu);
} // MultMenu

/**************************Multi-Edit Macro*********************************

 NAME:         MultiView

 DESCRIPTION:  Displays the current edit buffer, and allows cycling through each.

 PARAMETERS:	 /X= - The starting screen column.
							 /Y= - The starting screen line.

 RETURNS:      Nothing

						(C) Copyright 1992 American Cybernetics, Inc.
****************************************************************************/
macro MultiView
{
	int Cur, Initial, Prev, found = FALSE;
	int wattr, size, forward=1, line;
	int cwin = cur_window;
	int o_refresh = Refresh;
	str name, t_name, extra, wide;
	int done = FALSE;
	str OParm[4]='/O='+Str(0!=Parse_Int('/O=',MParm_Str));
	int o_block_stat, f_changed;

	if ((Global_Int('@MCMaxBuffers')< 1) || (Global_Int('@MCMaxBuffers') > MAX_BUFFERS)) {
		Set_Global_Int('@MCMaxBuffers', MAX_BUFFERS);
	}
	refresh = FALSE;
	Prev=Initial=Global_Int('@MCNextBuf');
	if ( Initial == 0 ) {
		RM("MEERROR^MessageBox /B=1/T=No Edit Buffer/M=There are no buffers! ");
	} else {
		do {
			wattr = window_attr;
			f_changed = file_changed;
			o_block_stat = 0;
			Cur=Global_Int('@MCNextBuf');
			if ( Cur == 0 ) {
				Cur++;
			}
			name = _BUFFER_NAME+Str(Cur);
			t_name = _BUFFER_NAME+char(Cur+0x40);
			if (Switch_File(name)) {
				f_changed = FALSE;
				extra = '';
 				wattr = window_attr;
				window_attr = 00;
				if (block_stat) {
					o_block_stat = block_stat;
					if ( block_line1 < block_line2 ) {
						size = (block_line2 - block_line1) + 2;
						line = block_line1;
					} else {
						size = (block_line1 - block_line2) + 2;
						line = block_line2;
					}
					if ( size > (screen_length/2)) {
						size = screen_length/2;
					}
					goto_line(line);
					RM('TOPWIN');
					goto_line(line);
				} else {
					eof;
					DOWN;
					size = 2;
				}
				wide = str(screen_width - 6);
			}	else {
				size = 1;
				extra = '/NEX=1';
				wide = str(1);
			}
			RM("MultiWindow /T=Browsing "+ t_name + extra +
					"/X=3/Y=5/W=" + wide + "/L=" + str(size));
			if ( o_block_stat ) {
				block_stat = o_block_stat;
			}
			window_attr = wattr;
			file_changed = f_changed;
			switch ( return_int ) {
				case  0:	/* Cancel */
//					Set_Global_Int('@MCNextBuf',Initial);
					done = TRUE;
					break;
				case  1:	/* Ok */
					Switch_window(cwin);
					RM('MultiPaste /Q=1'+OParm);
					done = TRUE;
					break;
				case 3: /* switch forward! */
					found = TRUE;
					Prev = Cur;
					forward = 1;
					RM("MultiSwitch /Q=1/D=1");
					break;
				case 4: /* switch backward! */
					found = TRUE;
					Prev = Cur;
					forward = 0;
					RM("MultiSwitch /Q=1/D=0");
					break;
				case 5:	/* DELETE the window! */
					delete_window;
					found = FALSE;
					Prev = Cur;
					RM("MultiSwitch /Q=1/D="+Str(forward));
					break;
				case 6: /* toggle the buffers "read_only" flag */
					Read_Only = !Read_Only;
					break;
				default:
					done = TRUE;
			}
		} while ( !done);
	}
	Switch_window(cwin);
	refresh = o_refresh;
	redraw;
}

macro MultiWindow TRANS2 NO_BREAK {
/*******************************************************************************
                                MULTI_EDIT MACRO

Name: MultiWindow

Description: Creates an editable window for inputing multiple lines of text.
      Uses the current window.


Parameters:   /X=nn         X position
              /Y=nn         Y position
              /W=nn         Width
              /L=nn         Length
              /T=str        Title string.
              /H=str        Help string.

               (C) Copyright 1991 by American Cybernetics, Inc.
*******************************************************************************/

  int  jx, ev_count, x, y, w, l ,T_Mode,
       old_refresh = refresh;
  str  event_str[20];

  int accept = 1,
      menu = menu_create,
			no_buff = parse_int('/NEX=', mparm_str ),
			accept
      ;

  refresh = FALSE;
  Set_Global_Int('MENU_LEVEL', Global_Int('MENU_LEVEL') + 1);
  T_Mode = Mode;
  Mode = Edit;
  x = parse_int('/X=', mparm_str );
  y = parse_int('/Y=', mparm_str );
  w = parse_int('/W=', mparm_str );
  l = parse_int('/L=', mparm_str );
  if(  x == 0  ) {
    x = 10;
  }
  if(  y == 0  ) {
    y = 3;
  }
  if(  w == 0  ) {
    w = 40;
  }
  if(  l == 0  ) {
    l = 10;
  }
  if( w > (screen_width - 3) ) {
    w=screen_width - 3;
  }
  if( l > (screen_length - 7) ) {
    l=screen_length - 7;
  }

  call set_events;

  right_margin = 2048;
	if ( read_only ) {
		return_str = "Read only";
	} else {
  	return_str = "Edit";
	}
	if ( no_buff )  {
  		menu_set_item(menu, 1,
        	"No buffer!","", '/L=2/W=10/C=15/HT=1',
        	10, 0, 0);
			accept = 4;
	} else {
  		menu_set_item(menu, 1,
        	return_str,"",
        	'/PB=1/QK=1/C=1/L=1/W=' + str(w) + '/HT=' + str(l) + '/WIN=' + str( cur_window ),
        	16, 0, 0);
			accept = 0;
	}
  return_int = menu;
  RM('USERIN^DATA_IN /HN=1/H=' + parse_str('/H=', mparm_str) + '/PRE=' + event_str +
        '/#=' + str(ev_count) + '/T=' + parse_str('/T=', mparm_str) + '/S=1' +
      '/X=' + str(x) + '/Y=' + str(y) +  '/A='+str(accept));
  goto exit;

set_events:
  ev_count = 1;
	if ( !no_buff ) {
  	menu_set_item( menu, ++ev_count,'OK', '', '/KC=<F10>/K2=68/R=1', 11, 0, 0);
	}
  menu_set_item( menu, ++ev_count,'Cancel','','/KC=<ESC>/K1=27/K2=1/R=0', 11, 0, 0);
  menu_set_item( menu, ++ev_count,'-','','/KC=<F2>/K2=60/R=4', 11, 0, 0);
  menu_set_item( menu, ++ev_count,'+','','/KC=<F3>/K2=61/R=3', 11, 0, 0);
	if ( !no_buff ) {
	  menu_set_item( menu, ++ev_count,'Delete','','/KC=<F5>/K2=63/R=5', 11, 0, 0);
	  menu_set_item( menu, ++ev_count,'Read Only','','/KC=<F6>/K2=64/R=6', 11, 0, 0);
	}
  menu_set_item( menu, ++ev_count,'Help', '','/KC=<F1>/K2=59/R=2', 11, 0, 0);

  call center_buttons;
  ret;

center_buttons:
  {
    int tw, xw = 0, jx, x1 = 0;
    for ( jx = 2; jx <= ev_count; jx++ )
    {
      tw = length( parse_str( '/KC=', menu_item_str(menu,jx,3))) +
              length(menu_item_str( menu, jx, 1 ));
      menu_set_int( menu, jx, 3, tw );
      xw += tw + 2;
    }
    xw -= 2;
    x1 = (w / 2) - (xw / 2 ) + 1;
    if(x1 < 1)
      x1 = 1;
    for ( jx = 2; jx <= ev_count; jx++ )
    {
      menu_set_str( menu, jx, 3, menu_item_str( menu, jx, 3 ) + '/C=' + str(x1) + '/L=' + str(l + 3) );
      x1 += menu_item_int( menu, jx, 3 ) + 2;
    }
    ret;
  }

EXIT:
  Set_Global_Int('MENU_LEVEL', Global_Int('MENU_LEVEL') - 1);
  Mode = T_Mode;
  refresh = old_refresh;
  menu_delete( menu );
}
